pub fn replace(replacer: &mut TextReplacer, input: &str) -> StringExpand description
Applies all configured replacement operations to the input text
pub fn replace(replacer: &mut TextReplacer, input: &str) -> StringApplies all configured replacement operations to the input text