pub fn replace_file(
replacer: &mut TextReplacer,
path: &str,
) -> Result<String, Box<EvalAltResult>>Expand description
Reads a file, applies all replacements, and returns the result as a string
pub fn replace_file(
replacer: &mut TextReplacer,
path: &str,
) -> Result<String, Box<EvalAltResult>>Reads a file, applies all replacements, and returns the result as a string